@@ -1,6 +1,6 @@
 package Net::Riak::Role::UserAgent;
 BEGIN {
-  $Net::Riak::Role::UserAgent::VERSION = '0.07';
+  $Net::Riak::Role::UserAgent::VERSION = '0.08';
 }
 
 # ABSTRACT: useragent for Net::Riak
@@ -14,6 +14,13 @@ has useragent => (
     lazy => 1,
     default => sub {
         my $self = shift;
+
+        # The Links header Riak returns (esp. for buckets) can get really long,
+        # so here increase the MaxLineLength LWP will accept (default = 8192)
+        my %opts = @LWP::Protocol::http::EXTRA_SOCK_OPTS;
+        $opts{MaxLineLength} = 65_536;
+        @LWP::Protocol::http::EXTRA_SOCK_OPTS = %opts;
+
         my $ua = LWP::UserAgent->new;
         $ua->timeout(3);
         $ua;
@@ -31,7 +38,7 @@ Net::Riak::Role::UserAgent - useragent for Net::Riak
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
